@@ -30,8 +30,8 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-#ifndef YY_MYSQL_VAR_LIB_JENKINS_JOBS_PERCONA_SERVER_5_5_SOURCE_TARBALL_WORKSPACE_SQL_SQL_YACC_H_INCLUDED
-# define YY_MYSQL_VAR_LIB_JENKINS_JOBS_PERCONA_SERVER_5_5_SOURCE_TARBALL_WORKSPACE_SQL_SQL_YACC_H_INCLUDED
+#ifndef YY_MYSQL_MNT_WORKSPACE_PERCONA_SERVER_5_5_SOURCE_TARBALL_SQL_SQL_YACC_H_INCLUDED
+# define YY_MYSQL_MNT_WORKSPACE_PERCONA_SERVER_5_5_SOURCE_TARBALL_SQL_SQL_YACC_H_INCLUDED
 /* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -1252,7 +1252,7 @@ extern int MYSQLdebug;
 
 union YYSTYPE
 {
-#line 731 "/var/lib/jenkins/jobs/percona-server-5.5-source-tarball/workspace/sql/sql_yacc.yy" /* yacc.c:1909  */
+#line 731 "/mnt/workspace/percona-server-5.5-source-tarball/sql/sql_yacc.yy" /* yacc.c:1909  */
 
   int  num;
   ulong ulong_num;
@@ -1301,7 +1301,7 @@ union YYSTYPE
   Diag_condition_item_name diag_condition_item_name;
   bool is_not_empty;
 
-#line 1305 "/var/lib/jenkins/jobs/percona-server-5.5-source-tarball/workspace/sql/sql_yacc.h" /* yacc.c:1909  */
+#line 1305 "/mnt/workspace/percona-server-5.5-source-tarball/sql/sql_yacc.h" /* yacc.c:1909  */
 };
 
 typedef union YYSTYPE YYSTYPE;
@@ -1313,4 +1313,4 @@ typedef union YYSTYPE YYSTYPE;
 
 int MYSQLparse (class THD *YYTHD);
 
-#endif /* !YY_MYSQL_VAR_LIB_JENKINS_JOBS_PERCONA_SERVER_5_5_SOURCE_TARBALL_WORKSPACE_SQL_SQL_YACC_H_INCLUDED  */
+#endif /* !YY_MYSQL_MNT_WORKSPACE_PERCONA_SERVER_5_5_SOURCE_TARBALL_SQL_SQL_YACC_H_INCLUDED  */
