@@ -230,17 +230,17 @@ static inline int count_leading_zeroes(int i, dec1 val)
   switch (i)
   {
   /* @note Intentional fallthrough in all case labels */
-  case 9: if (val >= 1000000000) break; ++ret;
-  case 8: if (val >= 100000000) break; ++ret;
-  case 7: if (val >= 10000000) break; ++ret;
-  case 6: if (val >= 1000000) break; ++ret;
-  case 5: if (val >= 100000) break; ++ret;
-  case 4: if (val >= 10000) break; ++ret;
-  case 3: if (val >= 1000) break; ++ret;
-  case 2: if (val >= 100) break; ++ret;
-  case 1: if (val >= 10) break; ++ret;
-  case 0: if (val >= 1) break; ++ret;
-  default: { DBUG_ASSERT(FALSE); }
+  case 9: if (val >= 1000000000) break; ++ret; // fallthrough
+  case 8: if (val >= 100000000) break; ++ret; // fallthrough
+  case 7: if (val >= 10000000) break; ++ret; // fallthrough
+  case 6: if (val >= 1000000) break; ++ret; // fallthrough
+  case 5: if (val >= 100000) break; ++ret; // fallthrough
+  case 4: if (val >= 10000) break; ++ret; // fallthrough
+  case 3: if (val >= 1000) break; ++ret; // fallthrough
+  case 2: if (val >= 100) break; ++ret; // fallthrough
+  case 1: if (val >= 10) break; ++ret; // fallthrough
+  case 0: if (val >= 1) break; ++ret; // fallthrough
+  default: { DBUG_ASSERT(FALSE); } // fallthrough
   }
   return ret;
 }
@@ -263,16 +263,16 @@ static inline int count_trailing_zeroes(int i, dec1 val)
   switch(i)
   {
   /* @note Intentional fallthrough in all case labels */
-  case 0: if ((val % 1) != 0) break; ++ret;
-  case 1: if ((val % 10) != 0) break; ++ret;
-  case 2: if ((val % 100) != 0) break; ++ret;
-  case 3: if ((val % 1000) != 0) break; ++ret;
-  case 4: if ((val % 10000) != 0) break; ++ret;
-  case 5: if ((val % 100000) != 0) break; ++ret;
-  case 6: if ((val % 1000000) != 0) break; ++ret;
-  case 7: if ((val % 10000000) != 0) break; ++ret;
-  case 8: if ((val % 100000000) != 0) break; ++ret;
-  case 9: if ((val % 1000000000) != 0) break; ++ret;
+  case 0: if ((val % 1) != 0) break; ++ret; // fallthrough
+  case 1: if ((val % 10) != 0) break; ++ret; // fallthrough
+  case 2: if ((val % 100) != 0) break; ++ret; // fallthrough
+  case 3: if ((val % 1000) != 0) break; ++ret; // fallthrough
+  case 4: if ((val % 10000) != 0) break; ++ret; // fallthrough
+  case 5: if ((val % 100000) != 0) break; ++ret; // fallthrough
+  case 6: if ((val % 1000000) != 0) break; ++ret; // fallthrough
+  case 7: if ((val % 10000000) != 0) break; ++ret; // fallthrough
+  case 8: if ((val % 100000000) != 0) break; ++ret; // fallthrough
+  case 9: if ((val % 1000000000) != 0) break; ++ret; // fallthrough
   default: { DBUG_ASSERT(FALSE); }
   }
   return ret;
@@ -737,7 +737,7 @@ int decimal_shift(decimal_t *dec, int shift)
     if (do_left)
     {
       do_mini_left_shift(dec, l_mini_shift, beg, end);
-      mini_shift=- l_mini_shift;
+      mini_shift= -l_mini_shift;
     }
     else
     {
